==> nomachine-8.11.3-1-x86_64.pkg.tar.zst: NX/lib/perl/nxnode/NXAuth.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2024 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXNODE, NX protocol compression and NX extensions to this software      #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
sub NXAuth::BEGIN{package NXAuth;no warnings;require strict;do{
"\x73\x74\x72\x69\x63\x74"->unimport ("\x72\x65\x66\x73")};}sub NXAuth::BEGIN{
package NXAuth;no warnings;require strict;do{"\x73\x74\x72\x69\x63\x74"->
unimport ("\x73\x75\x62\x73")};}sub NXAuth::BEGIN{package NXAuth;no warnings;
require Exporter;do{"\x45\x78\x70\x6f\x72\x74\x65\x72"->import};}sub 
NXAuth::BEGIN{package NXAuth;no warnings;require Common::NXBegin;do{
"\x43\x6f\x6d\x6d\x6f\x6e\x3a\x3a\x4e\x58\x42\x65\x67\x69\x6e"->import};}package
 NXAuth;no warnings;require Common::NXFile;(our (@ISA)=
"\x45\x78\x70\x6f\x72\x74\x65\x72");(our (@EXPORT)=(
"\x6e\x78\x61\x75\x74\x68\x41\x64\x64\x43\x6f\x6f\x6b\x69\x65",
"\x6e\x78\x61\x75\x74\x68\x52\x65\x6d\x6f\x76\x65\x43\x6f\x6f\x6b\x69\x65",
"\x6e\x78\x61\x75\x74\x68\x4c\x69\x73\x74\x43\x6f\x6f\x6b\x69\x65",
"\x6e\x78\x61\x75\x74\x68\x4c\x6f\x67\x43\x6f\x6f\x6b\x69\x65\x46\x72\x6f\x6d\x46\x69\x6c\x65"
));sub nxauthAddCookie{return (addCookie (@_));}sub nxauthLogCookieFromFile{(my $file
=shift (@_));my ($entries);(my (@command)=(
"\x2f\x75\x73\x72\x2f\x62\x69\x6e\x2f\x78\x61\x75\x74\x68","\x2d\x66",$file,
"\x6c\x69\x73\x74"));(my ($cmd_err,$cmd_out,$exit_value)=main::run_command ((
\@command),("")));}sub nxauthRemoveCookie{return (removeCookie (@_));}sub 
removeFromScript{(my $xauthorityFile=shift (@_));(my $script=shift (@_));if (((
not (defined ($xauthorityFile)))or ($xauthorityFile eq ("")))){Logger::warning (
"\x4d\x69\x73\x73\x69\x6e\x67\x20\x58\x61\x75\x74\x68\x6f\x72\x69\x74\x79\x20\x66\x69\x6c\x65"
);return ((0x172a+ 2540-0x2115));}Logger::debug ((
"\x47\x6f\x69\x6e\x67\x20\x74\x6f\x20\x6f\x70\x65\x6e\x20\x73\x63\x72\x69\x70\x74\x3a\x20"
.$script));(my $scriptFD=main::nxopen ($script,$NXBits::O_RDONLY,
(0x0040+ 5502-0x15be)));if ((not (defined ($scriptFD)))){(my $errorNumber=
libnxh::NXGetError ());(my $errorstring=libnxh::NXGetErrorString ());
Logger::warning (((
"\x43\x61\x6e\x6e\x6f\x74\x20\x6f\x70\x65\x6e\x20\x73\x63\x72\x69\x70\x74\x3a\x20"
.$script)."\x2e"));Logger::warning (((((
"\x45\x72\x72\x6f\x72\x20\x69\x73\x3a\x20".$errorNumber)."\x2c\x20").
$errorstring)."\x2e"));return ((0x1051+ 1070-0x147e));}while (main::nxreadLine (
$scriptFD,(\$_))){if ( /remove\s(\S*:\d{1,5})$/ ){(my $dpyname=$1);if ((not (
removeCookie ($xauthorityFile,$dpyname)))){(my $errorNumber=libnxh::NXGetError 
());(my $errorstring=libnxh::NXGetErrorString ());Logger::warning (((((
"\x43\x61\x6e\x6e\x6f\x74\x20\x72\x65\x6d\x6f\x76\x65\x20\x63\x6f\x6f\x6b\x69\x65\x20\x66\x6f\x72\x20"
.$dpyname)."\x20\x66\x72\x6f\x6d\x20").$xauthorityFile)."\x2e"));Logger::warning
 ((((("\x45\x72\x72\x6f\x72\x20\x69\x73\x3a\x20".$errorNumber)."\x2c\x20").
$errorstring)."\x2e"));}}}main::nxclose ($scriptFD);return (
(0x0360+ 5407-0x187f));}sub nxauthListCookie{return (listCookie (@_));}sub 
addCookie{(my $inputfilename=shift (@_));(my $dpyname=shift (@_));(my $protoname
=shift (@_));(my $hexkey=shift (@_));if (((not (defined ($inputfilename)))or (
$inputfilename eq ("")))){Logger::warning (
"\x43\x61\x6e\x6e\x6f\x74\x20\x61\x64\x64\x20\x63\x6f\x6f\x6b\x69\x65\x2c\x20\x6d\x69\x73\x73\x69\x6e\x67\x20\x69\x6e\x70\x75\x74\x20\x66\x69\x6c\x65\x20\x6e\x61\x6d\x65\x2e"
);return ((0x1575+ 278-0x168a));}if (((not (defined ($dpyname)))or ($dpyname eq 
("")))){Logger::warning (
"\x43\x61\x6e\x6e\x6f\x74\x20\x61\x64\x64\x20\x63\x6f\x6f\x6b\x69\x65\x2c\x20\x6d\x69\x73\x73\x69\x6e\x67\x20\x64\x69\x73\x70\x6c\x61\x79\x2e"
);return ((0x13fa+ 1102-0x1847));}if (((not (defined ($protoname)))or (
$protoname eq ("")))){Logger::warning (
"\x43\x61\x6e\x6e\x6f\x74\x20\x61\x64\x64\x20\x63\x6f\x6f\x6b\x69\x65\x2c\x20\x6d\x69\x73\x73\x69\x6e\x67\x20\x70\x72\x6f\x74\x6f\x6e\x61\x6d\x65\x2e"
);return ((0x10b5+ 1804-0x17c0));}if (((not (defined ($hexkey)))or ($hexkey eq 
("")))){Logger::warning (((
"\x43\x61\x6e\x6e\x6f\x74\x20\x61\x64\x64\x20\x63\x6f\x6f\x6b\x69\x65\x20\x66\x6f\x72\x20\x64\x69\x73\x70\x6c\x61\x79\x20"
.$dpyname).
"\x2c\x20\x6d\x69\x73\x73\x69\x6e\x67\x20\x68\x65\x78\x6b\x65\x79\x2e"));return 
((0x01bc+ 2108-0x09f7));}if (($hexkey eq "\x65\x6d\x70\x74\x79")){Logger::debug 
(
"\x53\x6b\x69\x70\x20\x61\x64\x64\x69\x6e\x67\x20\x65\x6d\x70\x74\x79\x20\x63\x6f\x6f\x6b\x69\x65\x2e"
);return ((0x067a+ 8202-0x2684));}(my $returnValue=libnxh::NXAddCookie (
$inputfilename,$dpyname,$protoname,$hexkey));if (($returnValue!=
(0x0ce9+ 2759-0x17b0))){(my $errorInt=libnxh::NXGetError ());(my $error=
libnxh::NXGetErrorName ());(my $errorString=libnxh::NXGetErrorString ());(my $path
=Common::NXFile::dirname ($inputfilename));(my $filename=
Common::NXFile::basename ($inputfilename));if (($error eq 
"\x45\x41\x43\x43\x45\x53")){(my $errorMessage=((((
"\x43\x61\x6e\x6e\x6f\x74\x20\x77\x72\x69\x74\x65\x20\x74\x6f\x20".$filename).
"\x20\x66\x69\x6c\x65\x20\x69\x6e\x20").$path).
"\x20\x6f\x6e\x20\x74\x68\x65\x20\x6c\x6f\x63\x61\x6c\x20\x68\x6f\x73\x74\x2e\x20\x50\x6c\x65\x61\x73\x65\x20\x76\x65\x72\x69\x66\x79\x20\x70\x65\x72\x6d\x69\x73\x73\x69\x6f\x6e\x20\x61\x74\x74\x72\x69\x62\x75\x74\x65\x73\x20\x66\x6f\x72\x20\x74\x68\x61\x74\x20\x66\x69\x6c\x65"
));main::nxwrite (main::nxgetSTDERR (),((
"\x4e\x58\x3e\x20\x35\x39\x38\x20\x45\x72\x72\x6f\x72\x3a\x20".$errorMessage).
"\x2e\x0a"));Logger::error ($errorMessage);main::clean_and_die (
"\x65\x43\x61\x6e\x6e\x6f\x74\x57\x72\x69\x74\x65\x54\x6f\x46\x69\x6c\x65\x4f\x6e\x54\x68\x65\x4c\x6f\x63\x61\x6c\x48\x6f\x73\x74\x56\x65\x72\x69\x66\x79\x50\x65\x72\x6d\x69\x73\x73\x69\x6f\x6e"
,$filename,$path);}else{(my $errorMessage=(((((
"\x43\x61\x6e\x6e\x6f\x74\x20\x77\x72\x69\x74\x65\x20\x74\x6f\x20".$filename).
"\x20\x66\x69\x6c\x65\x20\x69\x6e\x20").$path).
"\x20\x6f\x6e\x20\x74\x68\x65\x20\x6c\x6f\x63\x61\x6c\x20\x68\x6f\x73\x74\x2e\x20"
).$errorString));main::nxwrite (main::nxgetSTDERR (),((
"\x4e\x58\x3e\x20\x35\x39\x38\x20\x45\x72\x72\x6f\x72\x3a\x20".$errorMessage).
"\x0a"));Logger::error ($errorMessage);main::clean_and_die (
"\x65\x43\x61\x6e\x6e\x6f\x74\x57\x72\x69\x74\x65\x54\x6f\x46\x69\x6c\x65\x4f\x6e\x54\x68\x65\x4c\x6f\x63\x61\x6c\x48\x6f\x73\x74"
,$filename,$path,$errorString);}}return ($returnValue);}sub removeCookie{(my $inputfilename
=shift (@_));(my $dpyname=shift (@_));if (((not (defined ($inputfilename)))or (
$inputfilename eq ("")))){Logger::warning (
"\x43\x61\x6e\x6e\x6f\x74\x20\x72\x65\x6d\x6f\x76\x65\x20\x63\x6f\x6f\x6b\x69\x65\x2c\x20\x6d\x69\x73\x73\x69\x6e\x67\x20\x69\x6e\x70\x75\x74\x20\x66\x69\x6c\x65\x20\x6e\x61\x6d\x65\x2e"
);return ((0x1dc6+ 2036-0x25b9));}if (((not (defined ($dpyname)))or ($dpyname eq
 ("")))){Logger::warning (
"\x43\x61\x6e\x6e\x6f\x74\x20\x72\x65\x6d\x6f\x76\x65\x20\x63\x6f\x6f\x6b\x69\x65\x2c\x20\x6d\x69\x73\x73\x69\x6e\x67\x20\x64\x69\x73\x70\x6c\x61\x79\x2e"
);return ((0x0337+  38-0x035c));}return ((!libnxh::NXRemoveCookie (
$inputfilename,$dpyname)));}sub listCookie{(my $inputfilename=shift (@_));(my $nDisplay
=shift (@_));(my $ref_dpyNames=shift (@_));if (((not (defined ($inputfilename)))
or ($inputfilename eq ("")))){Logger::warning (
"\x43\x61\x6e\x6e\x6f\x74\x20\x6c\x69\x73\x74\x20\x63\x6f\x6f\x6b\x69\x65\x2c\x20\x6d\x69\x73\x73\x69\x6e\x67\x20\x69\x6e\x70\x75\x74\x20\x66\x69\x6c\x65\x20\x6e\x61\x6d\x65\x2e"
);return ((0x1b41+ 2591-0x255f));}if (((not (defined ($nDisplay)))or ($nDisplay 
eq ("")))){Logger::warning (
"\x43\x61\x6e\x6e\x6f\x74\x20\x6c\x69\x73\x74\x20\x63\x6f\x6f\x6b\x69\x65\x2c\x20\x6d\x69\x73\x73\x69\x6e\x67\x20\x64\x69\x73\x70\x6c\x61\x79\x2e"
);return ((0x1c5c+ 2408-0x25c3));}if ((not (defined ($ref_dpyNames)))){
Logger::warning (
"\x43\x61\x6e\x6e\x6f\x74\x20\x6c\x69\x73\x74\x20\x63\x6f\x6f\x6b\x69\x65\x2c\x20\x6d\x69\x73\x73\x69\x6e\x67\x20\x72\x65\x74\x75\x72\x6e\x20\x76\x61\x72\x69\x61\x62\x6c\x65\x2e"
);return ((0x026c+ 7339-0x1f16));}return ((!libnxh::NXListCookie ($inputfilename
,$nDisplay,$ref_dpyNames)));}"\x3f\x3f\x3f";

==> nomachine-8.12.12-1-x86_64.pkg.tar.zst: NX/lib/perl/nxnode/NXAuth.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2024 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXNODE, NX protocol compression and NX extensions to this software      #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
sub NXAuth::BEGIN{package NXAuth;no warnings;require strict;do{
"\x73\x74\x72\x69\x63\x74"->unimport ("\x72\x65\x66\x73")};}sub NXAuth::BEGIN{
package NXAuth;no warnings;require strict;do{"\x73\x74\x72\x69\x63\x74"->
unimport ("\x73\x75\x62\x73")};}sub NXAuth::BEGIN{package NXAuth;no warnings;
require Exporter;do{"\x45\x78\x70\x6f\x72\x74\x65\x72"->import};}sub 
NXAuth::BEGIN{package NXAuth;no warnings;require Common::NXBegin;do{
"\x43\x6f\x6d\x6d\x6f\x6e\x3a\x3a\x4e\x58\x42\x65\x67\x69\x6e"->import};}package
 NXAuth;no warnings;require Common::NXFile;(our (@ISA)=
"\x45\x78\x70\x6f\x72\x74\x65\x72");(our (@EXPORT)=(
"\x6e\x78\x61\x75\x74\x68\x41\x64\x64\x43\x6f\x6f\x6b\x69\x65",
"\x6e\x78\x61\x75\x74\x68\x52\x65\x6d\x6f\x76\x65\x43\x6f\x6f\x6b\x69\x65",
"\x6e\x78\x61\x75\x74\x68\x4c\x69\x73\x74\x43\x6f\x6f\x6b\x69\x65",
"\x6e\x78\x61\x75\x74\x68\x4c\x6f\x67\x43\x6f\x6f\x6b\x69\x65\x46\x72\x6f\x6d\x46\x69\x6c\x65"
));sub nxauthAddCookie{return (addCookie (@_));}sub nxauthLogCookieFromFile{(my $file
=shift (@_));my ($entries);(my (@command)=(
"\x2f\x75\x73\x72\x2f\x62\x69\x6e\x2f\x78\x61\x75\x74\x68","\x2d\x66",$file,
"\x6c\x69\x73\x74"));(my ($cmd_err,$cmd_out,$exit_value)=main::run_command ((
\@command),("")));}sub nxauthRemoveCookie{return (removeCookie (@_));}sub 
removeFromScript{(my $xauthorityFile=shift (@_));(my $script=shift (@_));if (((
not (defined ($xauthorityFile)))or ($xauthorityFile eq ("")))){Logger::warning (
"\x4d\x69\x73\x73\x69\x6e\x67\x20\x58\x61\x75\x74\x68\x6f\x72\x69\x74\x79\x20\x66\x69\x6c\x65"
);return ((0x0160+ 7397-0x1e44));}Logger::debug ((
"\x47\x6f\x69\x6e\x67\x20\x74\x6f\x20\x6f\x70\x65\x6e\x20\x73\x63\x72\x69\x70\x74\x3a\x20"
.$script));(my $scriptFD=main::nxopen ($script,$NXBits::O_RDONLY,
(0x0cc2+ 2454-0x1658)));if ((not (defined ($scriptFD)))){(my $errorNumber=
libnxh::NXGetError ());(my $errorstring=libnxh::NXGetErrorString ());
Logger::warning (((
"\x43\x61\x6e\x6e\x6f\x74\x20\x6f\x70\x65\x6e\x20\x73\x63\x72\x69\x70\x74\x3a\x20"
.$script)."\x2e"));Logger::warning (((((
"\x45\x72\x72\x6f\x72\x20\x69\x73\x3a\x20".$errorNumber)."\x2c\x20").
$errorstring)."\x2e"));return ((0x15cb+ 3587-0x23cd));}while (main::nxreadLine (
$scriptFD,(\$_))){if ( /remove\s(\S*:\d{1,5})$/ ){(my $dpyname=$1);if ((not (
removeCookie ($xauthorityFile,$dpyname)))){(my $errorNumber=libnxh::NXGetError 
());(my $errorstring=libnxh::NXGetErrorString ());Logger::warning (((((
"\x43\x61\x6e\x6e\x6f\x74\x20\x72\x65\x6d\x6f\x76\x65\x20\x63\x6f\x6f\x6b\x69\x65\x20\x66\x6f\x72\x20"
.$dpyname)."\x20\x66\x72\x6f\x6d\x20").$xauthorityFile)."\x2e"));Logger::warning
 ((((("\x45\x72\x72\x6f\x72\x20\x69\x73\x3a\x20".$errorNumber)."\x2c\x20").
$errorstring)."\x2e"));}}}main::nxclose ($scriptFD);return (
(0x05d0+ 5833-0x1c99));}sub nxauthListCookie{return (listCookie (@_));}sub 
addCookie{(my $inputfilename=shift (@_));(my $dpyname=shift (@_));(my $protoname
=shift (@_));(my $hexkey=shift (@_));if (((not (defined ($inputfilename)))or (
$inputfilename eq ("")))){Logger::warning (
"\x43\x61\x6e\x6e\x6f\x74\x20\x61\x64\x64\x20\x63\x6f\x6f\x6b\x69\x65\x2c\x20\x6d\x69\x73\x73\x69\x6e\x67\x20\x69\x6e\x70\x75\x74\x20\x66\x69\x6c\x65\x20\x6e\x61\x6d\x65\x2e"
);return ((0x1b4b+ 376-0x1cc2));}if (((not (defined ($dpyname)))or ($dpyname eq 
("")))){Logger::warning (
"\x43\x61\x6e\x6e\x6f\x74\x20\x61\x64\x64\x20\x63\x6f\x6f\x6b\x69\x65\x2c\x20\x6d\x69\x73\x73\x69\x6e\x67\x20\x64\x69\x73\x70\x6c\x61\x79\x2e"
);return ((0x1cd6+ 2431-0x2654));}if (((not (defined ($protoname)))or (
$protoname eq ("")))){Logger::warning (
"\x43\x61\x6e\x6e\x6f\x74\x20\x61\x64\x64\x20\x63\x6f\x6f\x6b\x69\x65\x2c\x20\x6d\x69\x73\x73\x69\x6e\x67\x20\x70\x72\x6f\x74\x6f\x6e\x61\x6d\x65\x2e"
);return ((0x20b1+ 1232-0x2580));}if (((not (defined ($hexkey)))or ($hexkey eq 
("")))){Logger::warning (((
"\x43\x61\x6e\x6e\x6f\x74\x20\x61\x64\x64\x20\x63\x6f\x6f\x6b\x69\x65\x20\x66\x6f\x72\x20\x64\x69\x73\x70\x6c\x61\x79\x20"
.$dpyname).
"\x2c\x20\x6d\x69\x73\x73\x69\x6e\x67\x20\x68\x65\x78\x6b\x65\x79\x2e"));return 
((0x07d2+ 1219-0x0c94));}if (($hexkey eq "\x65\x6d\x70\x74\x79")){Logger::debug 
(
"\x53\x6b\x69\x70\x20\x61\x64\x64\x69\x6e\x67\x20\x65\x6d\x70\x74\x79\x20\x63\x6f\x6f\x6b\x69\x65\x2e"
);return ((0x0cc8+ 5703-0x230f));}(my $returnValue=libnxh::NXAddCookie (
$inputfilename,$dpyname,$protoname,$hexkey));if (($returnValue!=
(0x16fa+ 1451-0x1ca5))){(my $errorInt=libnxh::NXGetError ());(my $error=
libnxh::NXGetErrorName ());(my $errorString=libnxh::NXGetErrorString ());(my $path
=Common::NXFile::dirname ($inputfilename));(my $filename=
Common::NXFile::basename ($inputfilename));if (($error eq 
"\x45\x41\x43\x43\x45\x53")){(my $errorMessage=((((
"\x43\x61\x6e\x6e\x6f\x74\x20\x77\x72\x69\x74\x65\x20\x74\x6f\x20".$filename).
"\x20\x66\x69\x6c\x65\x20\x69\x6e\x20").$path).
"\x20\x6f\x6e\x20\x74\x68\x65\x20\x6c\x6f\x63\x61\x6c\x20\x68\x6f\x73\x74\x2e\x20\x50\x6c\x65\x61\x73\x65\x20\x76\x65\x72\x69\x66\x79\x20\x70\x65\x72\x6d\x69\x73\x73\x69\x6f\x6e\x20\x61\x74\x74\x72\x69\x62\x75\x74\x65\x73\x20\x66\x6f\x72\x20\x74\x68\x61\x74\x20\x66\x69\x6c\x65"
));main::nxwrite (main::nxgetSTDERR (),((
"\x4e\x58\x3e\x20\x35\x39\x38\x20\x45\x72\x72\x6f\x72\x3a\x20".$errorMessage).
"\x2e\x0a"));Logger::error ($errorMessage);main::clean_and_die (
"\x65\x43\x61\x6e\x6e\x6f\x74\x57\x72\x69\x74\x65\x54\x6f\x46\x69\x6c\x65\x4f\x6e\x54\x68\x65\x4c\x6f\x63\x61\x6c\x48\x6f\x73\x74\x56\x65\x72\x69\x66\x79\x50\x65\x72\x6d\x69\x73\x73\x69\x6f\x6e"
,$filename,$path);}else{(my $errorMessage=(((((
"\x43\x61\x6e\x6e\x6f\x74\x20\x77\x72\x69\x74\x65\x20\x74\x6f\x20".$filename).
"\x20\x66\x69\x6c\x65\x20\x69\x6e\x20").$path).
"\x20\x6f\x6e\x20\x74\x68\x65\x20\x6c\x6f\x63\x61\x6c\x20\x68\x6f\x73\x74\x2e\x20"
).$errorString));main::nxwrite (main::nxgetSTDERR (),((
"\x4e\x58\x3e\x20\x35\x39\x38\x20\x45\x72\x72\x6f\x72\x3a\x20".$errorMessage).
"\x0a"));Logger::error ($errorMessage);main::clean_and_die (
"\x65\x43\x61\x6e\x6e\x6f\x74\x57\x72\x69\x74\x65\x54\x6f\x46\x69\x6c\x65\x4f\x6e\x54\x68\x65\x4c\x6f\x63\x61\x6c\x48\x6f\x73\x74"
,$filename,$path,$errorString);}}return ($returnValue);}sub removeCookie{(my $inputfilename
=shift (@_));(my $dpyname=shift (@_));if (((not (defined ($inputfilename)))or (
$inputfilename eq ("")))){Logger::warning (
"\x43\x61\x6e\x6e\x6f\x74\x20\x72\x65\x6d\x6f\x76\x65\x20\x63\x6f\x6f\x6b\x69\x65\x2c\x20\x6d\x69\x73\x73\x69\x6e\x67\x20\x69\x6e\x70\x75\x74\x20\x66\x69\x6c\x65\x20\x6e\x61\x6d\x65\x2e"
);return ((0x1e42+ 399-0x1fd0));}if (((not (defined ($dpyname)))or ($dpyname eq 
("")))){Logger::warning (
"\x43\x61\x6e\x6e\x6f\x74\x20\x72\x65\x6d\x6f\x76\x65\x20\x63\x6f\x6f\x6b\x69\x65\x2c\x20\x6d\x69\x73\x73\x69\x6e\x67\x20\x64\x69\x73\x70\x6c\x61\x79\x2e"
);return ((0x044b+ 3924-0x139e));}return ((!libnxh::NXRemoveCookie (
$inputfilename,$dpyname)));}sub listCookie{(my $inputfilename=shift (@_));(my $nDisplay
=shift (@_));(my $ref_dpyNames=shift (@_));if (((not (defined ($inputfilename)))
or ($inputfilename eq ("")))){Logger::warning (
"\x43\x61\x6e\x6e\x6f\x74\x20\x6c\x69\x73\x74\x20\x63\x6f\x6f\x6b\x69\x65\x2c\x20\x6d\x69\x73\x73\x69\x6e\x67\x20\x69\x6e\x70\x75\x74\x20\x66\x69\x6c\x65\x20\x6e\x61\x6d\x65\x2e"
);return ((0x0175+ 9176-0x254c));}if (((not (defined ($nDisplay)))or ($nDisplay 
eq ("")))){Logger::warning (
"\x43\x61\x6e\x6e\x6f\x74\x20\x6c\x69\x73\x74\x20\x63\x6f\x6f\x6b\x69\x65\x2c\x20\x6d\x69\x73\x73\x69\x6e\x67\x20\x64\x69\x73\x70\x6c\x61\x79\x2e"
);return ((0x04bc+ 7849-0x2364));}if ((not (defined ($ref_dpyNames)))){
Logger::warning (
"\x43\x61\x6e\x6e\x6f\x74\x20\x6c\x69\x73\x74\x20\x63\x6f\x6f\x6b\x69\x65\x2c\x20\x6d\x69\x73\x73\x69\x6e\x67\x20\x72\x65\x74\x75\x72\x6e\x20\x76\x61\x72\x69\x61\x62\x6c\x65\x2e"
);return ((0x0c78+ 173-0x0d24));}return ((!libnxh::NXListCookie ($inputfilename,
$nDisplay,$ref_dpyNames)));}"\x3f\x3f\x3f";
